@@ -25,7 +25,7 @@ class ResetPasswordView(mixins.CreateModelMixin, viewsets.GenericViewSet):
             user = user.id
         serializer = self.get_serializer(data={"user": user})
         serializer.is_valid(raise_exception=True)
-        self.perform_create(serializer)
+        serializer.save()
         headers = self.get_success_headers(serializer.data)
         return Response(status=status.HTTP_201_CREATED, headers=headers)
 
